#import "BookmarkEntity.h"

#import "AppDelegate.h"

@implementation BookmarkEntity

@synthesize name = _name;
@synthesize url = _url;
@synthesize position = _position;
@synthesize recordIdentifier = _recordIdentifier;
@synthesize parent = _parentIdentifier;
@synthesize updated;

+ (NSString*)entityName;
{
  return @"com.apple.bookmarks.Bookmark";
}

- (id)init
{
  if (![super init]) return nil;
  
  [self addObserver:self forKeyPath:@"parent" 
						options:NSKeyValueObservingOptionNew context:nil];
  [self addObserver:self forKeyPath:@"position" 
						options:NSKeyValueObservingOptionNew context:nil];
  [self addObserver:self forKeyPath:@"url" 
						options:NSKeyValueObservingOptionNew context:nil];
  [self addObserver:self forKeyPath:@"name" 
						options:NSKeyValueObservingOptionNew context:nil];
  
  return self;
}

- (void)observeValueForKeyPath:(NSString*)keyPath 
                      ofObject:(id)object 
                        change:(NSDictionary*)change 
                       context:(void*)context
{
	NSLog(@"%@ changed %@", _recordIdentifier, keyPath);
  [self setUpdated:YES];
}

- (void)dealloc
{
  [self removeObserver:self forKeyPath:@"parent"];
  [self removeObserver:self forKeyPath:@"position"];
  [self removeObserver:self forKeyPath:@"url"];
  [self removeObserver:self forKeyPath:@"name"];
  [_name release], _name = nil;
  [_url release], _url = nil;
  [_recordIdentifier release], _recordIdentifier = nil;
  [_parentIdentifier release], _parentIdentifier = nil;
  [super dealloc];
}

- (NSDictionary*)fullRecord;
{
  NSMutableDictionary *dict = [NSMutableDictionary dictionary];
  [dict setValue:[BookmarkEntity entityName] forKey:ISyncRecordEntityNameKey];
  [dict setValue:[self name] forKey:@"name"];
  [dict setValue:[NSNumber numberWithInt:[self position]] forKey:@"position"];
  [dict setValue:[self parent] forKey:@"parent"];
  return dict;
}

- (FolderEntity*)parentFolder
{
  return [[NSApp delegate] objectForRecordIdentifier:[self parent]];
}

- (BOOL)isLeaf;
{
  return YES;
}

- (NSString*)secondColumn;
{
  return [self url];
}

@end
